@@ -21,19 +21,6 @@ class DolphinTabWidget : public QTabWidget
     Q_OBJECT
 
 public:
-    /**
-     * @brief Controls where tabs are placed
-     */
-    enum TabPlacement {
-        /**
-          * The new tab is placed after the current tab
-          */
-        AfterCurrentTab,
-        /**
-          * The new tab is placed after the last tab
-          */
-        AfterLastTab
-    };
 
     /**
      * @param navigatorsWidget The navigatorsWidget which is always going to be connected
@@ -78,7 +65,7 @@ public:
      */
     bool isUrlOpen(const QUrl& url) const;
 
-signals:
+Q_SIGNALS:
     /**
      * Is emitted when the active view has been changed, by changing the current
      * tab or by activating another view when split view is enabled in the current
@@ -103,7 +90,7 @@ signals:
      */
     void currentUrlChanged(const QUrl& url);
 
-public slots:
+public Q_SLOTS:
     /**
      * Opens a new view with the current URL that is part of a tab and activates
      * the tab.
@@ -118,11 +105,9 @@ public slots:
 
     /**
      * Opens a new tab in the background showing the URL \a primaryUrl and the
-     * optional URL \a secondaryUrl. \a tabPlacement controls where the new tab
-     * is placed.
+     * optional URL \a secondaryUrl.
      */
-    void openNewTab(const QUrl &primaryUrl, const QUrl &secondaryUrl = QUrl(),
-                    DolphinTabWidget::TabPlacement tabPlacement = AfterLastTab);
+    void openNewTab(const QUrl &primaryUrl, const QUrl &secondaryUrl = QUrl());
 
     /**
      * Opens each directory in \p dirs in a separate tab. If \a splitView is set,
@@ -182,7 +167,7 @@ public slots:
     /** Moves all selected items to the inactive view. */
     void moveToInactiveSplitView();
 
-private slots:
+private Q_SLOTS:
     /**
      * Opens the tab with the index \a index in a new Dolphin instance and closes
      * this tab.
