@@ -1,23 +1,10 @@
-/***************************************************************************
- *   Copyright (C) 2006-2010 by Peter Penz <peter.penz19@gmail.com>        *
- *   Copyright (C) 2006 by Gregor Kališnik <gregor@podnapisi.net>          *
- *   Copyright (C) 2012 by Stuart Citrin <ctrn3e8@gmail.com>               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
- ***************************************************************************/
+/*
+ * SPDX-FileCopyrightText: 2006-2010 Peter Penz <peter.penz19@gmail.com>
+ * SPDX-FileCopyrightText: 2006 Gregor Kališnik <gregor@podnapisi.net>
+ * SPDX-FileCopyrightText: 2012 Stuart Citrin <ctrn3e8@gmail.com>
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
 #include "filterbar.h"
 
@@ -119,7 +106,7 @@ void FilterBar::keyReleaseEvent(QKeyEvent* event)
     switch (event->key()) {
     case Qt::Key_Escape:
         if (m_filterInput->text().isEmpty()) {
-            emit closeRequest();
+            Q_EMIT closeRequest();
         } else {
             m_filterInput->clear();
         }
@@ -127,7 +114,7 @@ void FilterBar::keyReleaseEvent(QKeyEvent* event)
 
     case Qt::Key_Enter:
     case Qt::Key_Return:
-        emit focusViewRequest();
+        Q_EMIT focusViewRequest();
         break;
 
     default:
