@@ -226,22 +226,8 @@ void KStandardItemListWidgetInformant::calculateCompactLayoutItemSizeHints(QVect
 void KStandardItemListWidgetInformant::calculateDetailsLayoutItemSizeHints(QVector<qreal>& logicalHeightHints, qreal& logicalWidthHint, const KItemListView* view) const
 {
     const KItemListStyleOption& option = view->styleOption();
-
-    float zoomLevel = 1;
-    if (option.iconSize >= KIconLoader::SizeEnormous) {
-        zoomLevel = 2;
-    } else if (option.iconSize >= KIconLoader::SizeHuge) {
-        zoomLevel = 1.8;
-    } else if (option.iconSize >= KIconLoader::SizeLarge) {
-        zoomLevel = 1.6;
-    } else if (option.iconSize >= KIconLoader::SizeMedium) {
-        zoomLevel = 1.4;
-    } else if (option.iconSize >= KIconLoader::SizeSmallMedium) {
-        zoomLevel = 1.2;
-    }
-
-    const qreal contentHeight = qMax<qreal>(option.iconSize, zoomLevel * option.fontMetrics.height());
-    logicalHeightHints.fill(contentHeight + 2 * option.padding);
+    const qreal height = option.padding * 2 + qMax(option.iconSize, option.fontMetrics.height());
+    logicalHeightHints.fill(height);
     logicalWidthHint = -1.0;
 }
 
@@ -417,7 +403,7 @@ void KStandardItemListWidget::paint(QPainter* painter, const QStyleOptionGraphic
         QPointF pos = ratingTextInfo->pos;
         const Qt::Alignment align = ratingTextInfo->staticText.textOption().alignment();
         if (align & Qt::AlignHCenter) {
-            pos.rx() += (size().width() - m_rating.width()) / 2 - 2;
+            pos.rx() += (size().width() - m_rating.width() / m_rating.devicePixelRatioF()) / 2 - 2;
         }
         painter->drawPixmap(pos, m_rating);
     }
@@ -1291,7 +1277,7 @@ void KStandardItemListWidget::updateIconsLayoutTextCache()
                 requiredWidth = m_customizedFontMetrics.horizontalAdvance(elidedText);
             } else if (role == "rating") {
                 // Use the width of the rating pixmap, because the rating text is empty.
-                requiredWidth = m_rating.width();
+                requiredWidth = m_rating.width() / m_rating.devicePixelRatioF();
             }
         }
         layout.endLayout();
