@@ -67,7 +67,7 @@ protected:
 };
 
 /**
- * @brief Itemlist widget implementation for KStandardItemListView and KStandardItemModel.
+ * @brief ItemList widget implementation for KStandardItemListView and KStandardItemModel.
  */
 class DOLPHIN_EXPORT KStandardItemListWidget : public KItemListWidget
 {
@@ -109,6 +109,12 @@ protected:
      */
     void invalidateCache();
 
+    /**
+     * Invalidates the icon cache which results in calling KStandardItemListWidget::refreshCache() as
+     * soon as the item needs to get repainted.
+     */
+    void invalidateIconCache();
+
     /**
      * Is called if the cache got invalidated by KStandardItemListWidget::invalidateCache().
      * The default implementation is empty.
