@@ -1,22 +1,9 @@
-/***************************************************************************
- *   Copyright (C) 2011 by Peter Penz <peter.penz19@gmail.com>             *
- *   Copyright (C) 2013 by Frank Reininghaus <frank78ac@googlemail.com>    *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
- ***************************************************************************/
+/*
+ * SPDX-FileCopyrightText: 2011 Peter Penz <peter.penz19@gmail.com>
+ * SPDX-FileCopyrightText: 2013 Frank Reininghaus <frank78ac@googlemail.com>
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
 #include "kdirectorycontentscounter.h"
 #include "kitemviews/kfileitemmodel.h"
@@ -128,7 +115,7 @@ void KDirectoryContentsCounter::slotResult(const QString& path, int count, long
     }
 
     // sends the results
-    emit result(resolvedPath, count, size);
+    Q_EMIT result(path, count, size);
 }
 
 void KDirectoryContentsCounter::slotDirWatchDirty(const QString& path)
@@ -173,12 +160,13 @@ void KDirectoryContentsCounter::slotItemsRemoved()
 
 void KDirectoryContentsCounter::startWorker(const QString& path)
 {
-    const bool alreadyInCache = s_cache->contains(path);
+    const QString resolvedPath = QFileInfo(path).canonicalFilePath();
+    const bool alreadyInCache = s_cache->contains(resolvedPath);
     if (alreadyInCache) {
         // fast path when in cache
         // will be updated later if result has changed
-        const auto pair = s_cache->value(path);
-        emit result(path, pair.first, pair.second);
+        const auto pair = s_cache->value(resolvedPath);
+        Q_EMIT result(path, pair.first, pair.second);
     }
 
     if (m_workerIsBusy) {
@@ -202,7 +190,7 @@ void KDirectoryContentsCounter::startWorker(const QString& path)
             options |= KDirectoryContentsCounterWorker::CountDirectoriesOnly;
         }
 
-        emit requestDirectoryContentsCount(path, options);
+        Q_EMIT requestDirectoryContentsCount(path, options);
         m_workerIsBusy = true;
     }
 }
