@@ -1,21 +1,7 @@
-/*  This file is part of the KDE project
-    Copyright (C) 2007 Matthias Kretz <kretz@kde.org>
-
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public License as
-    published by the Free Software Foundation; either version 2 of
-    the License, or (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+/*
+  SPDX-FileCopyrightText: 2007 Matthias Kretz <kretz@kde.org>
 
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "phononwidget.h"
@@ -237,7 +223,7 @@ void PhononWidget::play()
     }
 
     if (m_isVideo) {
-        emit hasVideoChanged(true);
+        Q_EMIT hasVideoChanged(true);
     }
 
     if (m_url != m_media->currentSource().url()) {
@@ -252,7 +238,7 @@ void PhononWidget::finished()
 {
     if (m_isVideo) {
         m_videoPlayer->hide();
-        emit hasVideoChanged(false);
+        Q_EMIT hasVideoChanged(false);
     }
 }
 
@@ -266,7 +252,7 @@ void PhononWidget::stop()
     if (m_media) {
         m_media->stop();
         m_videoPlayer->hide();
-        emit hasVideoChanged(false);
+        Q_EMIT hasVideoChanged(false);
     }
 }
 
