@@ -1,21 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2019 by Ismael Asensio <isma.af@mgmail.com>             *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA            *
- ***************************************************************************/
+/*
+ * SPDX-FileCopyrightText: 2019 Ismael Asensio <isma.af@mgmail.com>
+ *
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
 
 #include "dolphinquery.h"
 
@@ -73,6 +60,14 @@ namespace {
         return textParts;
     }
 #endif
+
+    QString trimChar(const QString& text, const QLatin1Char aChar)
+    {
+        const int start = text.startsWith(aChar) ? 1 : 0;
+        const int end = (text.length() > 1 && text.endsWith(aChar)) ? 1 : 0;
+
+        return text.mid(start, text.length() - start - end);
+    }
 }
 
 
@@ -83,6 +78,10 @@ DolphinQuery DolphinQuery::fromSearchUrl(const QUrl& searchUrl)
 
     if (searchUrl.scheme() == QLatin1String("baloosearch")) {
         model.parseBalooQuery();
+    } else if (searchUrl.scheme() == QLatin1String("tags")) {
+        // tags can contain # symbols or slashes within the Url
+        QString tag = trimChar(searchUrl.toString(QUrl::RemoveScheme), QLatin1Char('/'));
+        model.m_searchTerms << QStringLiteral("tag:%1").arg(tag);
     }
 
     return model;
@@ -92,6 +91,7 @@ bool DolphinQuery::supportsScheme(const QString& urlScheme)
 {
     static const QStringList supportedSchemes = {
         QStringLiteral("baloosearch"),
+        QStringLiteral("tags"),
     };
 
     return supportedSchemes.contains(urlScheme);
@@ -111,7 +111,7 @@ void DolphinQuery::parseBalooQuery()
     QString fileName;
 
     const QStringList subTerms = splitOutsideQuotes(query.searchString());
-    foreach (const QString& subTerm, subTerms) {
+    for (const QString& subTerm : subTerms) {
         const QString token = searchTermToken(subTerm);
         const QString value = stripQuotes(subTerm.mid(token.length()));
 
