@@ -38,7 +38,7 @@ DolphinSettingsDialog::DolphinSettingsDialog(const QUrl& url, QWidget* parent, K
     setMinimumSize(QSize(540, minSize.height()));
 
     setFaceType(List);
-    setWindowTitle(i18nc("@title:window", "Dolphin Preferences"));
+    setWindowTitle(i18nc("@title:window", "Configure"));
     QDialogButtonBox* box = new QDialogButtonBox(QDialogButtonBox::Ok
             | QDialogButtonBox::Apply | QDialogButtonBox::Cancel | QDialogButtonBox::RestoreDefaults);
     box->button(QDialogButtonBox::Apply)->setEnabled(false);
@@ -85,7 +85,8 @@ DolphinSettingsDialog::DolphinSettingsDialog(const QUrl& url, QWidget* parent, K
         QStringLiteral("open_in_new_tab"),
         QStringLiteral("open_in_new_window"),
         QStringLiteral("copy_location"),
-        QStringLiteral("duplicate")
+        QStringLiteral("duplicate"),
+        QStringLiteral("open_terminal"),
     });
     KPageWidgetItem* contextMenuSettingsFrame = addPage(contextMenuSettingsPage,
                                                         i18nc("@title:group", "Context Menu"));
@@ -98,9 +99,9 @@ DolphinSettingsDialog::DolphinSettingsDialog(const QUrl& url, QWidget* parent, K
     trashSettingsPage = createTrashSettingsPage(this);
 #endif
     if (trashSettingsPage) {
-        KPageWidgetItem* trashSettingsFrame = addPage(trashSettingsPage,
+        trashSettings = addPage(trashSettingsPage,
                                                      i18nc("@title:group", "Trash"));
-        trashSettingsFrame->setIcon(QIcon::fromTheme(QStringLiteral("user-trash")));
+        trashSettings->setIcon(QIcon::fromTheme(QStringLiteral("user-trash")));
         connect(trashSettingsPage, &TrashSettingsPage::changed, this, &DolphinSettingsDialog::enableApply);
     }
 
@@ -129,13 +130,13 @@ DolphinSettingsDialog::DolphinSettingsDialog(const QUrl& url, QWidget* parent, K
     }
 #endif
 
-    const KConfigGroup dialogConfig(KSharedConfig::openConfig(QStringLiteral("dolphinrc")), "SettingsDialog");
+    const KConfigGroup dialogConfig(KSharedConfig::openStateConfig(), "SettingsDialog");
     KWindowConfig::restoreWindowSize(windowHandle(), dialogConfig);
 }
 
 DolphinSettingsDialog::~DolphinSettingsDialog()
 {
-    KConfigGroup dialogConfig(KSharedConfig::openConfig(QStringLiteral("dolphinrc")), "SettingsDialog");
+    KConfigGroup dialogConfig(KSharedConfig::openStateConfig(), "SettingsDialog");
     KWindowConfig::saveWindowSize(windowHandle(), dialogConfig);
 }
 
