@@ -37,7 +37,7 @@ public:
 protected:
     void showEvent(QShowEvent* event) override;
 
-private slots:
+private Q_SLOTS:
     void configureService(const QModelIndex& index);
 
 private:
