@@ -34,7 +34,7 @@ public:
     /** @see SettingsPageBase::restoreDefaults() */
     void restoreDefaults() override;
 
-private slots:
+private Q_SLOTS:
     void slotSettingsChanged();
     void updateInitialViewOptions();
     void selectHomeUrl();
@@ -43,6 +43,7 @@ private slots:
 
 private:
     void loadSettings();
+    void showSetDefaultDirectoryError();
 
 private:
     QUrl m_url;
