@@ -6,13 +6,15 @@
 
 #include "search/dolphinsearchbox.h"
 
+#include <QStandardPaths>
 #include <QTest>
 
 class DolphinSearchBoxTest : public QObject
 {
     Q_OBJECT
 
-private slots:
+private Q_SLOTS:
+    void initTestCase();
     void init();
     void cleanup();
 
@@ -22,6 +24,11 @@ private:
     DolphinSearchBox* m_searchBox;
 };
 
+void DolphinSearchBoxTest::initTestCase()
+{
+    QStandardPaths::setTestModeEnabled(true);
+}
+
 void DolphinSearchBoxTest::init()
 {
     m_searchBox = new DolphinSearchBox();
