@@ -7,6 +7,7 @@
 
 #include <QTest>
 #include <QSignalSpy>
+#include <QStandardPaths>
 
 #include <random>
 
@@ -43,7 +44,8 @@ class KFileItemModelBenchmark : public QObject
 public:
     KFileItemModelBenchmark();
 
-private slots:
+private Q_SLOTS:
+    void initTestCase();
     void insertAndRemoveManyItems_data();
     void insertAndRemoveManyItems();
 
@@ -55,6 +57,11 @@ KFileItemModelBenchmark::KFileItemModelBenchmark()
 {
 }
 
+void KFileItemModelBenchmark::initTestCase()
+{
+    QStandardPaths::setTestModeEnabled(true);
+}
+
 void KFileItemModelBenchmark::insertAndRemoveManyItems_data()
 {
     QTest::addColumn<KFileItemList>("initialItems");
