@@ -7,7 +7,6 @@
 
 #include "dolphinview.h"
 
-#include "dolphin_detailsmodesettings.h"
 #include "dolphin_generalsettings.h"
 #include "dolphinitemlistview.h"
 #include "dolphinnewfilemenuobserver.h"
@@ -19,6 +18,7 @@
 #include "kitemviews/kitemlistheader.h"
 #include "kitemviews/kitemlistselectionmanager.h"
 #include "kitemviews/private/kitemlistroleeditor.h"
+#include "settings/viewmodes/viewmodesettings.h"
 #include "versioncontrol/versioncontrolobserver.h"
 #include "viewproperties.h"
 #include "views/tooltips/tooltipmanager.h"
@@ -56,7 +56,6 @@
 #include <QMenu>
 #include <QMimeDatabase>
 #include <QPixmapCache>
-#include <QPointer>
 #include <QScrollBar>
 #include <QSize>
 #include <QTimer>
@@ -463,6 +462,18 @@ bool DolphinView::sortFoldersFirst() const
     return m_model->sortDirectoriesFirst();
 }
 
+void DolphinView::setSortHiddenLast(bool hiddenLast)
+{
+    if (sortHiddenLast() != hiddenLast) {
+        updateSortHiddenLast(hiddenLast);
+    }
+}
+
+bool DolphinView::sortHiddenLast() const
+{
+    return m_model->sortHiddenLast();
+}
+
 void DolphinView::setVisibleRoles(const QList<QByteArray>& roles)
 {
     const QList<QByteArray> previousRoles = roles;
@@ -1373,6 +1384,17 @@ void DolphinView::updateSortFoldersFirst(bool foldersFirst)
     Q_EMIT sortFoldersFirstChanged(foldersFirst);
 }
 
+void DolphinView::updateSortHiddenLast(bool hiddenLast)
+{
+    ViewProperties props(viewPropertiesUrl());
+    props.setSortHiddenLast(hiddenLast);
+
+    m_model->setSortHiddenLast(hiddenLast);
+
+    Q_EMIT sortHiddenLastChanged(hiddenLast);
+}
+
+
 QPair<bool, QString> DolphinView::pasteInfo() const
 {
     const QMimeData *mimeData = QApplication::clipboard()->mimeData();
@@ -1508,16 +1530,12 @@ QUrl DolphinView::openItemAsFolderUrl(const KFileItem& item, const bool browseTh
 
 void DolphinView::resetZoomLevel()
 {
-    ViewModeSettings::ViewMode mode;
+    ViewModeSettings settings{m_mode};
+    settings.useDefaults(true);
+    const int defaultIconSize = settings.iconSize();
+    settings.useDefaults(false);
 
-    switch (m_mode) {
-    case IconsView:     mode = ViewModeSettings::IconsMode;   break;
-    case CompactView:   mode = ViewModeSettings::CompactMode; break;
-    case DetailsView:   mode = ViewModeSettings::DetailsMode; break;
-    }
-    const ViewModeSettings settings(mode);
-    const QSize iconSize = QSize(settings.iconSize(), settings.iconSize());
-    setZoomLevel(ZoomLevelInfo::zoomLevelForIconSize(iconSize));
+    setZoomLevel(ZoomLevelInfo::zoomLevelForIconSize(QSize(defaultIconSize, defaultIconSize)));
 }
 
 void DolphinView::observeCreatedItem(const QUrl& url)
@@ -1903,6 +1921,12 @@ void DolphinView::applyViewProperties(const ViewProperties& props)
         Q_EMIT sortFoldersFirstChanged(sortFoldersFirst);
     }
 
+    const bool sortHiddenLast = props.sortHiddenLast();
+    if (sortHiddenLast != m_model->sortHiddenLast()) {
+        m_model->setSortHiddenLast(sortHiddenLast);
+        Q_EMIT sortHiddenLastChanged(sortHiddenLast);
+    }
+
     const QList<QByteArray> visibleRoles = props.visibleRoles();
     if (visibleRoles != m_visibleRoles) {
         const QList<QByteArray> previousVisibleRoles = m_visibleRoles;
